﻿#include <avr/io.h>
#include <string.h>
#include "lcd.h"


void InitialisiereLCD(void);
void WarteAufLCD(void);
void BeschreibeLCD(u8 byte,u8 rs); //rs=0 für Befehle, rs=1 für Daten 
void FreigabeLCD(void);
void StringZuLCD(u8 *str);
void gotoXY(u8 x ,u8 y);

//===================================================== 
/** LCD initialisieren **/
void InitialisiereLCD(void) 
{    
     WarteAufLCD(); 			       // Warten bis LCD nach einschalten bereit
   BeschreibeLCD(m8bit_1zeile_5x8,0);  // 3x auf 8-Bit Modus,1 Zeilig und 5x8 Matrix setzten 
   BeschreibeLCD(m8bit_1zeile_5x8,0);  // ...
   BeschreibeLCD(m8bit_1zeile_5x8,0);  // ...
   BeschreibeLCD(m8bit_2zeile_5x8,0);  // Beginn der eigentlichen initialisierung
   BeschreibeLCD(display_aus,0);       // Display ausschalten
   BeschreibeLCD(loesche_lcd,0);       // Display löschen
   BeschreibeLCD(rechts,0);            // Kurser nach rechts, kein Display shift
   BeschreibeLCD(display_ein,0);       // Display einschalten
}

//===================================================== 
/** Das Busy Flag vom LCD-Port DB7 Abrufen ==> auf LCD warten bis fertig **/
void WarteAufLCD(void) 
{ 
   u8 busy=1; 
   do 
   { 
      DDRA =0xff; 
      PORTA=0xff;        //Alle Datenpinns auf 1
      DDRA =0x00;        //Alle Bits auf Eingang
      PORTB &=~(1<<EN);  //EN=0 ==> LCD BEfehl starten 
      PORTB &=~(1<<RS);  //RS=0 ==> Wenn RS=0 ==> Befehl 
      PORTB |= (1<<RW);  //RW=1 ==> Auf Read, weil lesen 
      PORTB |= (1<<EN);  //EN=1
	  busy=BF;           //Busy Flag in Variable busy auslesen 
   } 
   while(busy==1); 
   PORTB &=~(1<<EN);  //EN=0 ==> Den Befehl beenden 
   PORTB &=~(1<<RW);  //RW=0 ==> RW Ausschalten, für follgende Befehle
} 

//===================================================== 
/** Befehle auf LCD schreiben **/
void BeschreibeLCD(u8 byte,u8 rs) //rs=0 für Befehle, rs=1 für Daten 
{ 
   DDRA=0xff;          //PortA als Ausgang  
   PORTA=byte;
   if(rs==0){
     PORTB &=~(1<<RS); //RS=0
   }
   else{
     PORTB |= (1<<RS); //RS=1
   }
   PORTB &=~(1<<RW);   //RW=0
   FreigabeLCD();
   WarteAufLCD(); 
}

//===================================================== 
/** LCD Freigabe erzeugen **/
void FreigabeLCD(void)
{
   PORTB |= (1<<EN);  //EN=1
   PORTB &=~(1<<EN);  //EN=0
}


//===================================================== 
/** String auf LCD schreiben **/

void StringZuLCD(u8 *str)
{
  int i = 0;

  while( str[i] != '\0' ) {
    BeschreibeLCD( str[i],1 );
    i++;
  }
}

/*void StringZuLCD(u8 str[]) 
{ 
   u8 i; 
   for (i=0;i<strlen(str);i++) 
   { 
      if (i>15) 
         gotoXY(1,i-16); 
      BeschreibeLCD(str[i],1); 
   } 
} 

  
  
void gotoXY(u8 x ,u8 y) 
{ 
   //x is 0 or 1 
   //y is between 0 and 0x0f 
   u8 pos; 
   pos=x ? (zeile2+y):(zeile1+y) ; 
    
   DDRA=0xff; 
   PORTA=pos; 
   PORTB &=~(1<<RS);  //RS=0 ==> Wenn RS=0 ==> Befehl 
   PORTB &=~(1<<RW);  //RW=0 ==> Auf Read, weil lesen 
   FreigabeLCD();
   WarteAufLCD(); 
} */

/*void StringZuLCD (u8 *string)  
{
   while (*string){
    BeschreibeLCD(*string++,1);
   }
}
*/