﻿/**************************************************************** 
Mikrocontroller     : ATTiniy861V
Prozessor Takt      : 8.000000 MHz 
=================================================================
SPANNUNGSVERSORGUNG
    GND         ==> LCD PIN 1
    VCC ==> 5V  ==> LCD PIN 2
	VEE ==>Kontr==> LCD PIN 3
PORTB[0..2] ==> RS / RW / EN
    PB0 ==> RS  ==> LCD PIN 4
    PB1 ==> RW  ==> LCD PIN 5
    PB2 ==> EN  ==> LCD PIN 6
PORTA[0..7] ==>  DB0..DB7 LCD Datenbus
    PA0 ==> DB0 ==> LCD PIN 7
    PA1 ==> DB1 ==> LCD PIN 8
    PA2 ==> DB2 ==> LCD PIN 9
    PA3 ==> DB3 ==> LCD PIN 10
    PA4 ==> DB4 ==> LCD PIN 11
    PA5 ==> DB5 ==> LCD PIN 12
    PA6 ==> DB6 ==> LCD PIN 13
    PA7 ==> DB7 ==> LCD PIN 14
HINTERGRUNDBELEUCHTUNG
    LED+==>     ==> LCD PIN 15
    LED-==>     ==> LCD PIN 16
****************************************************************/ 
// Hier die verwendete Taktfrequenz in Hz eintragen, wichtig!
#ifndef F_CPU
#define F_CPU     8000000UL // Prozessor Takt
#warning kein F_CPU definiert
#endif

//Typedefs######################################################
typedef unsigned char  u8;
typedef   signed char  s8;

//Port Definitionen#############################################
#define RS        PB0		// Register Select ##### PORTB
#define RW        PB1		// Read/Write ########## PORTB
#define EN        PB2		// Enable ############## PORTB
#define BF        PA7       // Busy Flag ########### PORTA



/**************************************************************************************************/
/* LCD-Befehle (Siehe Display-Datenblatt)                                                         */
/* Diese Standardbefehle sollten mit den meisten kompatieblen Treibern funktionieren              */
/**************************************************************************************************/
/*                                                                                                */
#define schreibe_daten    0x00 /* Mit RS = 1                                                      */
#define loesche_lcd       0x01 /* Display löschen                                                 */
#define kurser_anfang     0x02 /* Kurser zur Anfangspossition                                     */
#define links             0x04 /* 1. Laufrichtung:links ==>I/D=0; Shift:aus==>S=0                 */
#define links_shift       0x05 /* 2. Laufrichtung:links ==>I/D=0; Shift:ein==>S=1                 */
#define rechts            0x06 /* 3. Laufrichtung:rechts==>I/D=1; Shift:aus==>S=0                 */
#define rechts_shift      0x07 /* 4. Laufrichtung:rechts==>I/D=1; Shift:ein==>S=1                 */
#define display_aus       0x08 /* 1. Display:aus==>D=0; Kurser:aus==>C=0; Kurser:Unterstrich==>B=0*/
#define display_ein       0x0C /* 5. Display:ein==>D=1; Kurser:aus==>C=0; Kurser:Unterstrich==>B=0*/
#define disp_unterstr     0x0E /* 7. Display:ein==>D=1; Kurser:ein==>C=1; Kurser:Unterstrich==>B=0*/
#define disp_blink        0x0F /* 8. Display:ein==>D=1; Kurser:ein==>C=1; Kurser:blink Block==>B=1*/
#define kurser_links      0x10 /* 1. Verschiebung:Kurser ==>S/C=0; Stelle:links ==>R/L=0          */
#define kurser_rechts     0x14 /* 2. Verschiebung:Kurser ==>S/C=0; Stelle:rechts==>R/L=1          */
#define display_links     0x18 /* 3. Verschiebung:Display==>S/C=1; Stelle:links ==>R/L=0          */
#define display_rechts    0x1C /* 4. Verschiebung:Display==>S/C=1; Stelle:links ==>R/L=1          */
#define m4bit_1zeile_5x8  0x20 /* 1. Mode:4-bit==>DL=0; Zeilen:1==>N=0; Punkt-Muster:5x8 ==>F=0   */
#define m4bit_1zeile_5x11 0x24 /* 2. Mode:4-bit==>DL=0; Zeilen:1==>N=0; Punkt-Muster:5x11==>F=1   */
#define m4bit_2zeile_5x8  0x28 /* 3. Mode:4-bit==>DL=0; Zeilen:2==>N=1; Punkt-Muster:5x8 ==>F=0   */
#define m4bit_2zeile_5x11 0x2C /* 4. Mode:4-bit==>DL=0; Zeilen:2==>N=1; Punkt-Muster:5x11==>F=1   */
#define m8bit_1zeile_5x8  0x30 /* 5. Mode:8-bit==>DL=1; Zeilen:1==>N=0; Punkt-Muster:5x8 ==>F=0   */
#define m8bit_1zeile_5x11 0x34 /* 6. Mode:8-bit==>DL=1; Zeilen:1==>N=0; Punkt-Muster:5x11==>F=1   */
#define m8bit_2zeile_5x8  0x38 /* 7. Mode:8-bit==>DL=1; Zeilen:2==>N=1; Punkt-Muster:5x8 ==>F=0   */
#define m8bit_2zeile_5x11 0x3C /* 8. Mode:8-bit==>DL=1; Zeilen:2==>N=1; Punkt-Muster:5x11==>F=1   */
/**************************************************************************************************/
#define zeile1            0x80 /* Adresse für die 1. Zeile                                        */
#define zeile2            0xC0 /* Adresse für die 2. Zeile                                        */
/**************************************************************************************************/
